kafka

package
v0.0.0-...-b7cfcfb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2016 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Overview

Copyright Mojing Inc. 2016 All Rights Reserved. Written by mint.zhao.chiu@gmail.com. github.com: https://www.github.com/mintzhao

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type KafkaCache

type KafkaCache struct {
	sync.Mutex
	// contains filtered or unexported fields
}

kafka cache

func NewKafkaCache

func NewKafkaCache() *KafkaCache

NewKafkaCache return kafka cache

func (*KafkaCache) Close

func (k *KafkaCache) Close() error

func (*KafkaCache) DocumentHash

func (k *KafkaCache) DocumentHash(raw []byte) string

func (*KafkaCache) DocumentID

func (k *KafkaCache) DocumentID(rawData []byte, t time.Time) string

func (*KafkaCache) Get

func (k *KafkaCache) Get(consumerName, topic string, count int64) ([]*protos.Document, error)

func (*KafkaCache) Put

func (k *KafkaCache) Put(appName string, raw []byte, metadata string, waitDuration time.Duration) (*protos.Document, error)

func (*KafkaCache) Subscribe

func (k *KafkaCache) Subscribe(consumerName, topic string) bool

func (*KafkaCache) Topic

func (k *KafkaCache) Topic(d time.Duration) string

Jump to