protos

package
v0.0.0-...-b7cfcfb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2016 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Copyright Mojing Inc. 2016 All Rights Reserved. Written by mint.zhao.chiu@gmail.com. github.com: https://www.github.com/mintzhao

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Package protos is a generated protocol buffer package.

It is generated from these files:

poe.proto

It has these top-level messages:

Document

Index

Constants

This section is empty.

Variables

var DocProofStatus_name = map[int32]string{
	0: "NOT_SPECIFIAL",
	1: "NOT_PROOFED",
	2: "ALREADY_PROOFED",
}
var DocProofStatus_value = map[string]int32{
	"NOT_SPECIFIAL":   0,
	"NOT_PROOFED":     1,
	"ALREADY_PROOFED": 2,
}

Functions

This section is empty.

Types

type DocProofStatus

type DocProofStatus int32
const (
	DocProofStatus_NOT_SPECIFIAL   DocProofStatus = 0
	DocProofStatus_NOT_PROOFED     DocProofStatus = 1
	DocProofStatus_ALREADY_PROOFED DocProofStatus = 2
)

func (DocProofStatus) EnumDescriptor

func (DocProofStatus) EnumDescriptor() ([]byte, []int)

func (DocProofStatus) String

func (x DocProofStatus) String() string

type Document

type Document struct {
	// unique id
	Id string `protobuf:"bytes,1,opt,name=id" json:"id,omitempty"`
	// raw data
	// bytes raw = 2;
	// hash(block)
	BlockDigest string `protobuf:"bytes,3,opt,name=blockDigest" json:"blockDigest,omitempty"`
	// submit time
	SubmitTime int64 `protobuf:"varint,4,opt,name=submitTime" json:"submitTime,omitempty"`
	// proof time
	ProofTime int64 `protobuf:"varint,5,opt,name=proofTime" json:"proofTime,omitempty"`
	// document hash
	Hash string `protobuf:"bytes,6,opt,name=hash" json:"hash,omitempty"`
	// wait time
	WaitDuration int64 `protobuf:"varint,7,opt,name=waitDuration" json:"waitDuration,omitempty"`
	// metadata
	Metadata string `protobuf:"bytes,8,opt,name=metadata" json:"metadata,omitempty"`
	// txid
	Txid string `protobuf:"bytes,9,opt,name=txid" json:"txid,omitempty"`
	// sign
	Sign string `protobuf:"bytes,10,opt,name=sign" json:"sign,omitempty"`
	// appName
	AppName string `protobuf:"bytes,11,opt,name=appName" json:"appName,omitempty"`
	// proofed flag
	ProofStatus DocProofStatus `protobuf:"varint,12,opt,name=proofStatus,enum=protos.DocProofStatus" json:"proofStatus,omitempty"`
}

ProofObject

func (*Document) Descriptor

func (*Document) Descriptor() ([]byte, []int)

func (*Document) ProtoMessage

func (*Document) ProtoMessage()

func (*Document) Reset

func (m *Document) Reset()

func (*Document) String

func (m *Document) String() string

type ProofStat

type ProofStat struct {
	StartTime   int64 `json:"startTime"`
	EndTime     int64 `json:"endTime"`
	TotalDocs   int64 `json:"totalDocs"`
	WaitDocs    int64 `json:"waitDocs"`
	ProofedDocs int64 `json:"proofedDocs"`
}

ProofStat

Jump to