Documentation
¶
Overview ¶
Copyright Mojing Inc. 2016 All Rights Reserved. Written by mint.zhao.chiu@gmail.com. github.com: https://www.github.com/mintzhao
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Blockchain ¶
type Blockchain struct {
// contains filtered or unexported fields
}
Blockchain
func NewBlockchain ¶
func NewBlockchain(cc cache.CacheInterface, persister persist.PersistInterface) (*Blockchain, error)
NewBlockchain returns a blockchain handler
func (*Blockchain) Close ¶
func (bc *Blockchain) Close() error
func (*Blockchain) RegisterProof ¶
func (bc *Blockchain) RegisterProof(docs []*protos.Document)
RegisterProof
func (*Blockchain) VerifyDocs ¶
func (bc *Blockchain) VerifyDocs(docs []*protos.Document) bool
VerifyDocs verify whether documents are unchanged