Documentation
¶
Overview ¶
Copyright Mojing Inc. 2016 All Rights Reserved. Written by mint.zhao.chiu@gmail.com. github.com: https://www.github.com/mintzhao
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CacheInterface ¶
type CacheInterface interface {
// Put puts raw data into cache, separated by topic.
Put(appName string, raw []byte, metadata string, waitDuration time.Duration) (*protos.Document, error)
// Get gets documents which related to `topic`, and the number of documents is `count`, if not enough, returns all
Get(consumer, topic string, count int64) ([]*protos.Document, error)
// once the consumer subscribed the topic, they will get documents which related to the topic
Subscribe(consumer, topic string) bool
// Topic returns which topic can be used based on proof_wait_period
Topic(d time.Duration) string
// DocumentID
DocumentID(rawData []byte, t time.Time) string
// DocumentHash
DocumentHash(raw []byte) string
// Close closes cache adapter, if error occurs, return it
Close() error
}
cache request
Click to show internal directories.
Click to hide internal directories.