Documentation
¶
Overview ¶
Copyright Mojing Inc. 2016 All Rights Reserved. Written by mint.zhao.chiu@gmail.com. github.com: https://www.github.com/mintzhao
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type PersistInterface ¶
type PersistInterface interface {
// PutDocsIntoDB puts documents into database
PutDocsIntoDB(docs []*protos.Document) error
// GetDocFromDBByDocID get document info from database based on document id
GetDocFromDBByDocID(docID string) (*protos.Document, error)
// SetDocsBlockDigest sets documents's blockDigest, which indicate where documents belongs to
SetDocsBlockDigest(docIDs []string, digest, txid string) error
// SetDocSignature sets document's signature
SetDocSignature(docID, sign string) error
// FindDocsByBlockDigest finds documents belong to a same digest
FindDocsByBlockDigest(digest string) ([]*protos.Document, error)
// FindDocsByHash
FindDocsByHash(hash string) ([]*protos.Document, error)
// FindDocs
FindDocs(appName string, proofStatus protos.DocProofStatus, count int) ([]*protos.Document, error)
// DocProofStat
DocProofStat(sTime, eTime time.Time) *protos.ProofStat
// Close closes persister
Close() error
}
PersistInterface
func NewPersister ¶
func NewPersister(cc cache.CacheInterface) PersistInterface
NewPersister returns a persister based on config